@@ -59,7 +59,9 @@ try:
     _qtapp.setStyle('Fusion')
     
     # Dark theme
-    if settings['dark_theme']: from . import _fusion_theme    
+    if settings['dark_theme']: 
+        from . import _fusion_theme
+        pylab.style.use('dark_background')
 
 except:
     _warn("pyqtgraph version 0.11 or higher is required (use a conda or pip install) if you wish to use dialogs or egg.")
@@ -71,10 +73,6 @@ except:
 
 
 
-# some defaults
-_mpl.rcParams['figure.facecolor']='w'
-
-
 if _sys.version[0] == '2':
     _warn("Spinmob no longer supports Python 2.7 or below (which itself will not be maintained after Jan 1, 2020). USE AT YOUR OWN RISK!")
 
@@ -87,5 +85,14 @@ plot.tweaks._pylab_colormap._settings = settings
 
 instaprint = tweaks.instaprint
 
+# Default settings
+_defaults = dict(
+    dark_theme            = False,
+    font_size_legend      = 9,
+    font_size_axis_labels = 12,
+    font_size_title       = 10,)
+
+for _k in _defaults: 
+    if not _k in settings.keys(): settings[_k] = _defaults[_k]
 
 
